@@ -7,13 +7,24 @@
 
 .__pakret__ <- new.env(parent = emptyenv())
 
-set <- function(...) {
+set <- function(..., .add = FALSE) {
   items <- eval(substitute(alist(...)))
   for (key in names(items)) {
-    .__pakret__[[key]] <- eval(items[[key]], envir = parent.frame())
+    .__pakret__[[key]] <- eval_set(items, key, .add)
   }
 }
 
+eval_set <- function(x, key, add, envir = parent.frame(2L)) {
+  x <- eval(x[[key]], envir = envir)
+  if (is_string(x) && has_placeholder(x)) {
+    x <- list(str = as_sprintf(x), vars = vars(x))
+  }
+  if (add) {
+    x <- c(get(key), x)
+  }
+  x
+}
+
 get <- function(x) {
   .__pakret__[[x]]
 }
