@@ -10,14 +10,15 @@ test_that("pkrt_list() makes a list of citations", {
 test_that("citation lists can be turned into data frames", {
   load_foo()
   load_bar()
-  citations <- pkrt_list("foo", "bar")
+  local_pkg("zzz", Version = "0.1.0")
+  citations <- pkrt_list("zzz", "bar", "foo")
 
   expect_equal(
     as.data.frame(citations),
     data.frame(
-      Package = c("bar", "foo"),
-      Version = c("0.2.0", "1.0.0"),
-      Reference = c("@bar", "@foo")
+      Package = c("bar", "foo", "zzz"),
+      Version = c("0.2.0", "1.0.0", "0.1.0"),
+      Reference = c("@bar", "@foo", "@zzz")
     )
   )
 })
