@@ -1,12 +1,10 @@
 test_that("pkrt() cites and references packages", {
-  skip_on_os("windows")
   dir <- local_files(make_template(lines = "`r pkrt('foo')`"))
   res <- read_local_file(dir)
   expect_snapshot(cat(res))
 })
 
 test_that("bib entries are properly appended to bib files", {
-  skip_on_os("windows")
   template <- make_template(lines = "`r pkrt('foo')` `r pkrt('bar')`")
   dir <- local_files(template)
   res <- read_local_file(dir, target = "bib")
@@ -14,13 +12,12 @@ test_that("bib entries are properly appended to bib files", {
 
   load_bar()
   template <- make_template(lines = "`r pkrt('foo')`")
-  dir <- local_files(template, bib = local_set(lines = get_reference("bar")))
+  dir <- local_files(template, bib = local_set(lines = ref_get("bar")))
   res <- read_local_file(dir, target = "bib")
   expect_snapshot(cat(res))
 })
 
 test_that("multi-bib entries are properly handled", {
-  skip_on_os("windows")
   template <- dedent("
     ---
     bibliography: %s
@@ -45,20 +42,18 @@ test_that("multi-bib entries are properly handled", {
 })
 
 test_that("citing the same package again doesn't add a new bib entry", {
-  skip_on_os("windows")
   dir <- local_files(make_template(lines = strrep("`r pkrt('foo')`", 2L)))
   res <- read_local_file(dir, target = "bib")
   expect_length(extract(res, "(?m)^@"), 1L)
 })
 
 test_that("citing no packages doesn't modify bib files", {
-  skip_on_os("windows")
   load_foo()
-  citation <- get_reference("foo")
+  citation <- ref_get("foo")
   template <- make_template(lines = "")
   dir <- local_files(template, bib = local_set(lines = citation))
   res <- read_local_file(dir, target = "bib")
-  expect_equal(res, paste0(citation, eol()))
+  expect_equal(res, paste0(citation, "\n"))
 })
 
 test_that("pkrt() cites R", {
@@ -68,7 +63,6 @@ test_that("pkrt() cites R", {
 })
 
 test_that("pakret handles references that have a premade key (#18)", {
-  skip_on_os("windows")
   template <- dedent("
     ---
     bibliography: %s
@@ -89,6 +83,57 @@ test_that("pakret handles references that have a premade key (#18)", {
   expect_match(res, "@Manual\\{baz,")
 })
 
+test_that("pakret works with modified frame stacks (#30)", {
+  template <- dedent("
+    ---
+    bibliography: %s
+    ---
+    ```{r}
+    (function() library(pakret))()
+    pakret:::load_foo()
+    ```
+    `r pkrt('foo')`
+  ")
+  dir <- local_files(template)
+  res <- read_local_file(dir, target = "bib")
+
+  expect_match(res, "@Manual\\{foo,")
+})
+
+test_that("pakret preserves the case of package and single-letter names", {
+  template <- dedent("
+    ---
+    bibliography: %s
+    ---
+    ```{r}
+    library(pakret)
+    pakret:::local_pkg('baz', Title = 'A Simple R Test With a Protected {B}')
+    ```
+    `r pkrt('baz')`
+  ")
+  dir <- local_files(template)
+  res <- read_local_file(dir, target = "bib")
+
+  expect_snapshot(cat(res))
+})
+
+test_that("pakret creates bib files if needed", {
+  template <- dedent("
+    ---
+    bibliography: pkrt.bib
+    ---
+    ```{r}
+    library(pakret)
+    pakret:::load_foo()
+    ```
+    `r pkrt('foo')`
+  ")
+  dir <- local_files(template, bib = NULL)
+  res <- read_local_file(dir, target = "bib")
+
+  expect_match(res, "@Manual\\{foo,")
+})
+
 # errors
 
 test_that("pkrt() gives meaningful error messages", {
